#
# spec file for package epplet-base
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           epplet-base
Version:        0.10
Release:        78.17
Summary:        Applets for the Enlightenment DR16 Window Manager
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://www.enlightenment.org/
Source:         epplets-%{version}.tar.bz2
Patch0:         epplets-unsuficient_include.patch
Patch1:         epplet-base-linking.patch
BuildRequires:  Mesa-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  imlib2-devel >= 1.2.0
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(xext)

%description
Epplets are programs designed to work with the Enlightenment Window
Manager Version 0.16.  Generally they are quite small and
provide a quick way for a user to perform simple tasks or view
information.

%prep
%setup -q -n epplets-%{version}
%patch0
%patch1 -p1

%build
autoreconf --force --install
CFLAGS="$CFLAGS %{optflags} -fno-strict-aliasing" \
%configure --disable-static --with-pic --enable-fsstd
make %{?_smp_mflags}

%check
export MALLOC_CHECK_=2
make %{?_smp_mflags} check
unset MALLOC_CHECK_

%install
make DESTDIR=%{buildroot} libdir=%{_libdir} install
find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-, root, root, 755)
%{_bindir}/E*epplet
%{_includedir}/epplet.h
%{_libdir}/libepplet*
%dir %{_datadir}/e16
%{_datadir}/e16/epplet_icons
%{_datadir}/e16/epplet_data

%changelog
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing Xext build dependency
- Run spec-cleaner
* Wed Sep 27 2017 dimstar@opensuse.org
- Drop esound-devel BuildRequires: esound has been obsoleted by a
  couple sound servers by now
* Mon Nov 24 2014 simon@simotek.net
- Update summary and description to indicate that this package only
  works for enlightenment DR16, it won't run on e17 and later
* Mon Aug 18 2014 jengelh@inai.de
- Drop unused build-time requirements
* Mon Mar 26 2012 dimstar@opensuse.org
- Add epplet-base-linking.patch: Fix linking.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Jan 11 2010 vuntz@opensuse.org
- Remove unneeded gtk-devel BuildRequires.
* Fri Jan  8 2010 ro@suse.de
- remove unused imlib-devel from buildrequires (imlib2 is used)
* Wed Apr 15 2009 ro@suse.de
- buildfix: refresh patches
* Fri Jun 13 2008 crrodriguez@suse.de
- disable unusable static libraries
* Thu Apr 17 2008 matejcik@suse.cz
- update to 0.10
  * mostly cleanup and bugfixes
* Thu Dec 14 2006 ro@suse.de
- move from usr/X11R6 to usr
* Fri Sep  8 2006 pnemec@suse.cz
- fix gcc warning in E-memwatch plugin
* Fri Jul 28 2006 ro@suse.de
- added Mesa-devel to BuildRequires
* Wed Jul 12 2006 pnemec@suse.cz
- updated to version 0.9
  cleaned specs and configs
  fixed memory leaks
- added patch to fix not included library
  (epplets-unsuficient_include.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 19 2005 pnemec@suse.cz
- fix gcc warnings
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Mon Apr 26 2004 ro@suse.de
- use -fno-strict-aliasing
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Jun 16 2003 kukuk@suse.de
- Add missing directories to filelist
* Mon Sep 23 2002 pmladek@suse.cz
- added alsa and alsa-devel to neededforbuild because of esound
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed May  8 2002 mfabian@suse.de
- use %%{_lib} to make it build on x86_64
* Wed Apr 24 2002 ro@suse.de
- fix for automake-1.6 (remove duplicated lines in Makefile.am)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Thu Feb  1 2001 violiet@suse.de
- added SuSE series: xap
* Sat Jan 27 2001 violiet@suse.de
- NEW epplet-base package version to 0.5
